@@ -275,6 +275,7 @@ print_engine_info(Recog *recog)
   jlog("----------------------- System Information begin ---------------------\n");
   j_put_header(fp);
   j_put_compile_defs(fp);
+  j_put_library_defs(fp);
   jlog("\n");
   
   /* print current argument setting to log */
@@ -959,7 +960,6 @@ print_engine_info(Recog *recog)
     } else {
       jlog("\t    long-term DC removal = off\n");
     }
-    jlog("\t    long-term DC removal = off\n");
     if (jconf->preprocess.level_coef != 1.0) {
       jlog("\t    level scaling factor = %.2f\n", jconf->preprocess.level_coef);
     } else {
