@@ -1148,6 +1148,11 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
       if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
       jconf->amnow->analysis.cmn_update = FALSE;
       continue;
+    } else if (strmatch(argv[i],"-cmnstatic")) { /* no map, just use static parameter */
+      if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
+      jconf->amnow->analysis.map_cmn = FALSE;
+      jconf->amnow->analysis.cmn_update = FALSE;
+      continue;
     } else if (strmatch(argv[i],"-cmnmapweight")) { /* CMN weight for MAP */
       if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
       GET_TMPARG;
@@ -1329,6 +1334,22 @@ opt_parse(int argc, char *argv[], char *cwd, Jconf *jconf)
       GET_TMPARG;
       jconf->outprob_outfile = filepath(tmparg, cwd);
       continue;
+    } else if (strmatch(argv[i],"-dnnconf")) {
+      if (!check_section(jconf, argv[i], JCONF_OPT_AM)) return FALSE; 
+      GET_TMPARG;
+      tmparg = filepath(tmparg, cwd);
+      if (dnn_config_file_parse(tmparg, jconf->amnow) == FALSE) {
+	jlog("ERROR: m_options: failed to read %s\n", tmparg);
+	free(tmparg);
+	return FALSE;
+      }
+      if (jconf->amnow->dnn.optionstring) {
+	if (config_string_parse(jconf->amnow->dnn.optionstring, jconf) == FALSE) {
+	  return FALSE;
+	}
+      }
+      free(tmparg);
+      continue;
     }
     if (argv[i][0] == '-' && strlen(argv[i]) == 2) {
       /* 1-letter options */
