@@ -39,9 +39,9 @@
  * 
  */
 /*
- * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2016 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2016 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -1248,7 +1248,7 @@ wchmm_fbs(HTK_Param *param, RecogProcess *r, int cate_bgn, int cate_num)
 
   /* ꥢ */
   /* work area */
-  NEXTWORD fornoise; /* Dummy NEXTWORD data for short-pause insertion handling */
+  NEXTWORD fornoise = {0}; /* Dummy NEXTWORD data for short-pause insertion handling */
 
   NEXTWORD **nextword, *nwroot;	/* buffer to store predicted words */
   int maxnwnum;			/* current allocated number of words in nextword */
