@@ -12,13 +12,13 @@
  * @author Akinobu LEE
  * @date   Wed Feb 16 07:09:25 2005
  *
- * $Revision: 1.5 $
+ * $Revision: 1.7 $
  * 
  */
 /*
- * Copyright (c) 1991-2012 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2016 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2012 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2016 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -55,12 +55,15 @@ rd(int fd, char *data, int *len, int maxlen)
       read(fd,((char *)len) + off, toread);
 #endif
     if (ret <= 0) {  
-      if (ret < 0) jlog("Error: rdwt: failed to read data at %d / %d\n", count, len);
+      if (ret < 0) jlog("Error: rdwt: failed to read data\n");
       return(-1);
     }
     toread -= ret;
     off += ret;
   }
+#ifdef WORDS_BIGENDIAN
+  swap_bytes((char *)len, sizeof(int), 1);
+#endif
   if (*len > maxlen) {
     jlog("Error: rdwt: transfer data length exceeded: %d (>%d)\n", len, maxlen);
     return(-1);
@@ -98,6 +101,9 @@ wt(int fd, char *data, int len)
 {
   int tmpbytes;
 
+#ifdef WORDS_BIGENDIAN
+  swap_bytes((char *)&len, sizeof(int), 1);
+#endif
   /* len == 0 is used to tell end of segment ack */
   if ((tmpbytes=
 #ifdef WINSOCK
@@ -109,6 +115,9 @@ wt(int fd, char *data, int len)
     /*jlog( "failed to write num\n");*/
     return(-1);
   }
+#ifdef WORDS_BIGENDIAN
+  swap_bytes((char *)&len, sizeof(int), 1);
+#endif
   if (len > 0) {
     if ((tmpbytes=
 #ifdef WINSOCK
