@@ -22,16 +22,14 @@
  * 
  */
 /*
- * Copyright (c) 1991-2013 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2016 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2013 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2016 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
 /* mkbingram --- make binary n-gram for JULIUS from ARPA standard format */
 
-/* $Id: mkbingram.c,v 1.7 2013/06/20 17:14:27 sumomo Exp $ */
-
 #include <sent/stddefs.h>
 #include <sent/ngram2.h>
 #include <sys/stat.h>
@@ -50,7 +48,9 @@ usage(char *s)
   printf("    -nlr file       forward  N-gram in ARPA format\n");
   printf("    -nrl file       backward N-gram in ARPA format\n");
   printf("    -d bingramfile  Julius binary N-gram file input\n");
+#if defined(HAVE_WINNLS) || defined(HAVE_ICONV)
   printf("    -c from to      convert character code\n");
+#endif
   printf("    -swap           swap \"%s\" and \"%s\"\n", BEGIN_WORD_DEFAULT, END_WORD_DEFAULT);
   printf("\n      When both \"-nlr\" and \"-nrl\" are specified, \n");
   printf("      Julius will use the BACKWARD N-gram as main LM\n");
@@ -114,6 +114,7 @@ main(int argc, char *argv[])
 	  return -1;
 	}
       } else if (argv[i][1] == 'c') {
+#if defined(HAVE_WINNLS) || defined(HAVE_ICONV)
 	if (++i >= argc) {
 	  printf("Error: no argument for option \"%s\"\n", argv[i]);
 	  usage(argv[0]);
@@ -128,6 +129,11 @@ main(int argc, char *argv[])
 	}
 	to_code = strcpy((char*)mymalloc(strlen(argv[i])+1),argv[i]);
 	charconv_enabled = TRUE;
+#else
+	printf("Error: this binary was not built with character code conversion\n");
+	usage(argv[0]);
+	return -1;
+#endif
       } else if (argv[i][1] == 's') {
 	force_swap = TRUE;
       }
@@ -207,7 +213,9 @@ main(int argc, char *argv[])
 
   print_ngram_info(stdout, ngram);
   
+#if defined(HAVE_WINNLS) || defined(HAVE_ICONV)
   if (charconv_enabled == TRUE) {
+    int fail_count = 0;
     /* do character conversion */
     if (charconv_setup(from_code, to_code) == -1) {
       fprintf(stderr, "failed to setup character convertsion\n");
@@ -215,12 +223,20 @@ main(int argc, char *argv[])
     }
     buf = (char *)mymalloc(4096);
     for (w = 0; w < ngram->max_word_num; w++) {
-      charconv(ngram->wname[w], buf, 4096);
-      ngram->wname[w] = mybmalloc2(strlen(buf)+1, &(ngram->mroot));
-      strcpy(ngram->wname[w], buf);
+      if (charconv(ngram->wname[w], buf, 4096) == NULL) {
+	fprintf(stderr, "failed to convert, leave original string #%d \"%s\"\n", w, ngram->wname[w]);
+	fail_count++;
+      } else {
+	ngram->wname[w] = mybmalloc2(strlen(buf)+1, &(ngram->mroot));
+	strcpy(ngram->wname[w], buf);
+      }
     }
     free(buf);
+    if (fail_count > 0) {
+      fprintf(stderr, "total %d of %d words was not converted\n", fail_count, ngram->max_word_num);
+    }
   }
+#endif
 
   /* write in JULIUS binary format */
   if ((fp = fopen_writefile(outfile)) == NULL) {
