@@ -1,5 +1,5 @@
 /* Version string */
-#define LIBSENT_VERSION "4.4"
+#define LIBSENT_VERSION "4.4.1"
 
 /* Audio API name */
 #define AUDIO_API_NAME "pa-dsound"
@@ -120,3 +120,6 @@
 
 /* Define if MBR support is enabled */
 #undef USE_MBR
+
+/* Define if use ARM NEON instruction for DNN */
+#undef USE_ARM_NEON
